diff graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/expression/SLEqualNode.java @ 16761:e5e1013c04fd

SL: adapt SL for @Generic to @Fallback rename.
author Christian Humer <christian.humer@gmail.com>
date Mon, 11 Aug 2014 15:57:47 +0200
parents abe7128ca473
children c0455554d45b
line wrap: on
line diff
--- a/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/expression/SLEqualNode.java	Mon Aug 11 15:57:47 2014 +0200
+++ b/graal/com.oracle.truffle.sl/src/com/oracle/truffle/sl/nodes/expression/SLEqualNode.java	Mon Aug 11 15:57:47 2014 +0200
@@ -83,11 +83,11 @@
     }
 
     /**
      * The {@link Generic} annotation informs the Truffle DSL that this method should be executed
      * when no {@link Specialization specialized method} matches. The operand types must be
      * {@link Object}.
      */
-    @Generic
+    @Fallback
     protected boolean equal(Object left, Object right) {
         /*
          * We covered all the cases that can return true in specializations. If we compare two
@@ -83,11 +83,11 @@
 
     /**
-     * The {@link Generic} annotation informs the Truffle DSL that this method should be executed
+     * The {@link Fallback} annotation informs the Truffle DSL that this method should be executed
      * when no {@link Specialization specialized method} matches. The operand types must be
      * {@link Object}.